aboutsummaryrefslogtreecommitdiffstats
path: root/nexus/arch.h
diff options
context:
space:
mode:
authorDavid Shah <dave@ds0.me>2020-10-07 12:10:52 +0100
committerDavid Shah <dave@ds0.me>2020-11-30 08:45:27 +0000
commit2f822a3b79ef322802162e727dfe37fe3872966b (patch)
tree57b5e123ae759032cec06e63b5635c01bfd9d10c /nexus/arch.h
parent46536773f4432e4ced47b7c82fbcc4d6101308f8 (diff)
downloadnextpnr-2f822a3b79ef322802162e727dfe37fe3872966b.tar.gz
nextpnr-2f822a3b79ef322802162e727dfe37fe3872966b.tar.bz2
nextpnr-2f822a3b79ef322802162e727dfe37fe3872966b.zip
nexus: Packing helper functions
Signed-off-by: David Shah <dave@ds0.me>
Diffstat (limited to 'nexus/arch.h')
-rw-r--r--nexus/arch.h29
1 files changed, 20 insertions, 9 deletions
diff --git a/nexus/arch.h b/nexus/arch.h
index 0b058bd7..47276f42 100644
--- a/nexus/arch.h
+++ b/nexus/arch.h
@@ -771,15 +771,26 @@ enum CellPinStyle
PINDEF_0 = 0x10, // connect to 0 if not used
PINDEF_1 = 0x20, // connect to 1 if not used
- PINSTYLE_CIB = 0x11, // 'CIB' signal, floats high but explicitly zeroed if not used
- PINSTYLE_CLK = 0x07, // CLK type signal, invertible and defaults to disconnected
- PINSTYLE_CE = 0x27, // CE type signal, invertible and defaults to enabled
- PINSTYLE_LSR = 0x17, // LSR type signal, invertible and defaults to not reset
- PINSTYLE_DEDI = 0x00, // dedicated signals, leave alone
- PINSTYLE_PU = 0x21, // signals that float high and default high
-
- PINSTYLE_INV_PD = 0x17, // invertible, pull down by default
- PINSTYLE_INV_PU = 0x27, // invertible, pull up by default
+ PINGLB_CLK = 0x100, // pin is a 'clock' for global purposes
+
+ PINSTYLE_CIB = 0x011, // 'CIB' signal, floats high but explicitly zeroed if not used
+ PINSTYLE_CLK = 0x107, // CLK type signal, invertible and defaults to disconnected
+ PINSTYLE_CE = 0x027, // CE type signal, invertible and defaults to enabled
+ PINSTYLE_LSR = 0x017, // LSR type signal, invertible and defaults to not reset
+ PINSTYLE_DEDI = 0x000, // dedicated signals, leave alone
+ PINSTYLE_PU = 0x021, // signals that float high and default high
+
+ PINSTYLE_INV_PD = 0x017, // invertible, pull down by default
+ PINSTYLE_INV_PU = 0x027, // invertible, pull up by default
+};
+
+// This represents the mux options for a pin
+enum CellPinMux
+{
+ PINMUX_SIG = 0,
+ PINMUX_0 = 1,
+ PINMUX_1 = 2,
+ PINMUX_INV = 3,
};
// -----------------------------------------------------------------------